pub trait ComplexIndexMut<Idx>: ComplexIndex<Idx> {
// Required method
fn datac_mut(&mut self, index: Idx) -> &mut Self::Output;
}Expand description
Like std::ops::IndexMut
but with a different method name so that it can be used to implement a additional range
accessor for complex data.
Note if indexers will return an empty array in case the vector isn’t complex.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".